#!/bin/bash

# Packager: p.r.faasse (prfaasse)
# Sources location : 
# - http://www.freedesktop.org/~davidsansome/gtk-qt-engine-0.7.tar.bz2

# program name/version
softversion='0.7'
softname='gtk-qt-engine'

(

# architecture/package version
arch='i486'
cpu='i686'
packageversion='46.1'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
$softname: Adapts GTK programs to use the KDE/Q style(s)
$softname:
$softname: This is a package that adapts a GTK program so that it can
$softname: appear more like a 'native' KDE/Qt application
$softname: 
$softname: This will show up as an entry in the "Control Center"
$softname: in 'Appearance & Themes' -> 'GTK Styles and Fonts'
$softname:
$softname:
$softname:
$softname: 
EOF

# extract sources
srcdir="$softname"
cd $buildir
rm -rf $srcdir
tar jxvf $softname-$softversion.tar.bz2
cd $srcdir

# set correct permissions
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
 
# configure package for compilation
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --localstatedir=/var/lib \
   --mandir=/usr/man \
   --sysconfdir=/etc \
   --program-prefix="" \
   --program-suffix=""
   
# compile package
make 

# install package to the target directory
make install DESTDIR=$dest
    
# copy the doc files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   AUTHORS COPYING COPYING.LIB ChangeLog INSTALL NEWS README \
   $dest/usr/doc/$softname-$softversion
chmod 755 $dest/usr/doc/$softname-$softversion

# compress the man pages
gzip -9 $dest/usr/man/man?/*.?

# strip executables 
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
chown -R root.root $dest/usr/src/$softname-$softversion

# change files ownerships for the $dest/usr/bin and $dest/usr/sbin
chown -R root.root $dest/usr/bin

#
# fix: i have to 'remove' one file from the destination, or else the
# resulting entry in kcontrol will appear twice... Not what we want...
# I 'just' rename it to make it 'unusable': that way we can keep trace
# of what happens...
#
(
 echo "-- Removing the /usr/share/applications/kcmgtk-xdg.desktop file -----"
 cd $dest/usr/share/applications
 mv kcmgtk-xdg.desktop kcm-gtk.desktop.notinzenwalk
)

# make the package and move it to the build directory
cd $dest
makepkg -p -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

#
# zenwalk requires dependencies files nowadays...
#
requiredbuilder -z $package.tgz >$package.dep

) 2>&1 | tee $softname-info.txt
